parse_mint_tokens

Function parse_mint_tokens 

fn parse_mint_tokens(log: &Log) -> (Address, Address)
Parses user and validator token addresses from a FeeAMM::Mint event log.

WARNING: Caller is responsible for ensuring the input is a FeeAMM::Mint event.