trait FilterExt {
// Required method
fn with_minted_tokens<'a>(
self,
tokens: impl Iterator<Item = &'a Address>,
) -> Self;
}Required Methods
fn with_minted_tokens<'a>( self, tokens: impl Iterator<Item = &'a Address>, ) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl FilterExt for Filter
impl FilterExt for Filter
Sourcefn with_minted_tokens<'a>(
self,
tokens: impl Iterator<Item = &'a Address>,
) -> Self
fn with_minted_tokens<'a>( self, tokens: impl Iterator<Item = &'a Address>, ) -> Self
Restricts the filter to events where both, topic 2 and topic 3, are among the input tokens.
WARNING: Caller must ensure that the filter targets fee AMM mint events:
Mint(address indexed sender, address indexed userToken, address indexed validatorToken, ..)